#
# Copyright (C) 2019-2020 Cochise Ruhulessin
#
# This file is part of python-iam.
#
# python-iam is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 3.
#
# python-iam is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with python-iam.  If not, see <https://www.gnu.org/licenses/>.


TEST_USER1_ID           = '00000000-0000-0000-0000-000000000001'
TEST_USER1_EMAIL        = 'testuser1@test.iam.unimatrixone.io'
TEST_USER1_PHONENUMBER  = "+31612345678"
TEST_PASSWORD           = 'password'


MESSAGE_QUERY_PARAM = 'm'

MESSAGE_TOKEN_SESSION_KEY = 'iam.token'
