# Generated by Django 3.0.4 on 2020-03-19 03:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0018_platformagreementlanguage'),
    ]

    operations = [
        migrations.AlterField(
            model_name='platformagreementlanguage',
            name='checksum',
            field=models.CharField(db_column='checksum', editable=False, max_length=128, unique=True),
        ),
    ]
