# Generated by Django 3.0.4 on 2020-03-07 00:21

from django.db import migrations


def create_default_realm(apps, schema_editor):
    Realm = apps.get_model('iam.Realm')
    Realm.objects.create(name='default', label='default')


def create_master_realm(apps, schema_editor):
    Realm = apps.get_model('iam.Realm')
    Realm.objects.create(name='master', label='Master')


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_default_realm),
        migrations.RunPython(create_master_realm),
    ]
