# Generated by Django 3.0.4 on 2020-03-07 02:18

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0003_emailprincipal'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailprincipal',
            name='subject',
            field=models.ForeignKey(db_column='subject_id', on_delete=django.db.models.deletion.CASCADE, related_name='email', to=settings.AUTH_USER_MODEL),
        ),
    ]
