# Generated by Django 3.0.4 on 2020-03-19 05:10

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0020_acceptedplatformagreement'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='platformagreement',
            options={'default_permissions': [], 'ordering': ['-effective'], 'verbose_name': 'Platform Agreement', 'verbose_name_plural': 'Platform Agreements'},
        ),
        migrations.AlterField(
            model_name='acceptedplatformagreement',
            name='agreement',
            field=models.ForeignKey(db_column='agreement_checksum', on_delete=django.db.models.deletion.PROTECT, related_name='accepted', to='iam.PlatformAgreementLanguage', to_field='checksum'),
        ),
        migrations.AlterField(
            model_name='acceptedplatformagreement',
            name='subject',
            field=models.ForeignKey(db_column='subject_id', on_delete=django.db.models.deletion.CASCADE, related_name='agreements', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='platformagreementlanguage',
            name='agreement',
            field=models.ForeignKey(db_column='agreement_slug', on_delete=django.db.models.deletion.CASCADE, related_name='languages', to='iam.PlatformAgreement'),
        ),
    ]
