# Generated by Django 3.0.4 on 2020-03-18 11:12

from django.db import migrations, models
import django.db.models.deletion
import unimatrix.lib.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0011_auto_20200318_1042'),
    ]

    operations = [
        migrations.CreateModel(
            name='SubjectRegistration',
            fields=[
                ('using', models.OneToOneField(db_column='principal_id', on_delete=django.db.models.deletion.PROTECT, primary_key=True, serialize=False, to='iam.Principal')),
                ('host', models.GenericIPAddressField(db_column='host')),
                ('platform', models.CharField(db_column='platform', max_length=127)),
                ('registrar', models.CharField(db_column='registrar', default='self', max_length=127)),
                ('timestamp', models.BigIntegerField(db_column='timestamp', default=unimatrix.lib.timezone.now)),
                ('tsr', models.BinaryField(db_column='tsr', default=bytes)),
            ],
            options={
                'db_table': 'subjectregistrations',
                'default_permissions': [],
            },
        ),
    ]
