# Generated by Django 3.0.4 on 2020-03-07 02:18

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0002_auto_20200307_0021'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailPrincipal',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.EmailField(db_column='value', max_length=254)),
                ('realm', models.ForeignKey(db_column='realm_name', on_delete=django.db.models.deletion.PROTECT, to='iam.Realm')),
                ('subject', models.ForeignKey(db_column='subject_id', on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'emailprincipals',
                'default_permissions': [],
                'unique_together': {('realm', 'value'), ('subject', 'value')},
            },
        ),
    ]
