# Generated by Django 3.0.4 on 2020-03-18 21:46

from django.db import migrations


def create_jail_realm(apps, schema_editor):
    Realm = apps.get_model('iam.Realm')
    Realm.objects.create(name='jail', label='Jail')


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0015_auto_20200318_1830'),
    ]

    operations = [
        migrations.RunPython(create_jail_realm)
    ]
