# Generated by Django 3.0.4 on 2020-03-07 03:42

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0004_auto_20200307_0218'),
    ]

    operations = [
        migrations.CreateModel(
            name='PasswordCredential',
            fields=[
                ('subject', models.OneToOneField(db_column='subject_id', on_delete=django.db.models.deletion.CASCADE, primary_key=True, related_name='password', serialize=False, to=settings.AUTH_USER_MODEL)),
                ('value', models.CharField(db_column='value', max_length=128)),
            ],
            options={
                'db_table': 'passwordcredentials',
                'default_permissions': [],
            },
        ),
    ]
