# Generated by Django 3.0.4 on 2020-03-18 18:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0014_subjectbooleanproperty'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='subjectregistration',
            options={'default_permissions': [], 'verbose_name': 'Registration', 'verbose_name_plural': 'Registrations'},
        ),
    ]
