# Generated by Django 3.0.4 on 2020-03-15 11:52

from django.db import migrations, models
import iam.domain.logincode
import unimatrix.lib.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0006_principal'),
    ]

    operations = [
        migrations.CreateModel(
            name='LoginCode',
            fields=[
                ('subject', models.UUIDField(db_column='subject', primary_key=True, serialize=False)),
                ('code', models.CharField(db_column='code', default=iam.domain.logincode.LoginCode.new, max_length=127)),
                ('attempts', models.PositiveIntegerField(db_column='attempts', default=0)),
                ('generated', models.BigIntegerField(db_column='generated', default=unimatrix.lib.timezone.now)),
            ],
            options={
                'db_table': 'logincodes',
                'default_permissions': [],
            },
        ),
    ]
