# Generated by Django 3.0.4 on 2020-03-18 18:02

from django.conf import settings
from django.db import migrations


def create_staff_realm(apps, schema_editor):
    Realm = apps.get_model('iam.Realm')
    Realm.objects.create(name=settings.IAM_STAFF_REALM, label='Backoffice')


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0012_subjectregistration'),
    ]

    operations = [
        migrations.RunPython(create_staff_realm)
    ]
