# Generated by Django 3.0.4 on 2020-03-18 10:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0010_subject_kind'),
    ]

    operations = [
        migrations.AlterField(
            model_name='principal',
            name='id',
            field=models.BigAutoField(db_column='id', primary_key=True, serialize=False),
        ),
    ]
