from .acceptagreement import AcceptAgreementFormView
from .choosenames import ChooseNamesFormView
from .debug import DebugView
from .login import LoginView
from .logintoken import LoginTokenView
from .magiclink import MagicLinkView
from .register import RegisterView
from .resetcredentials import ResetCredentialsView
