# Generated by Django 3.0.4 on 2020-03-17 23:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0009_auto_20200316_0256'),
    ]

    operations = [
        migrations.AddField(
            model_name='subject',
            name='kind',
            field=models.CharField(db_column='kind', default='User', max_length=63),
        ),
    ]
