# Generated by Django 3.0.4 on 2020-03-16 02:52

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0007_logincode'),
    ]

    operations = [
        migrations.CreateModel(
            name='SubjectStringProperty',
            fields=[
                ('id', models.BigAutoField(db_column='id', primary_key=True, serialize=False)),
                ('kind', models.CharField(db_column='kind', max_length=127)),
                ('value', models.CharField(db_column='value', max_length=127)),
                ('subject', models.ForeignKey(db_column='subject_id', on_delete=django.db.models.deletion.CASCADE, related_name='stringproperties', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'subjectstringproperties',
                'default_permissions': [],
                'default_related_name': 'stringproperties',
            },
        ),
    ]
