# Generated by Django 3.0.4 on 2020-03-07 00:21

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Realm',
            fields=[
                ('name', models.CharField(db_column='name', max_length=64, primary_key=True, serialize=False)),
                ('label', models.CharField(db_column='label', max_length=64)),
            ],
            options={
                'db_table': 'realms',
                'default_permissions': [],
            },
        ),
        migrations.CreateModel(
            name='Subject',
            fields=[
                ('id', models.UUIDField(db_column='id', default=uuid.uuid4, primary_key=True, serialize=False)),
                ('realm', models.ForeignKey(db_column='realm_name', default='default', on_delete=django.db.models.deletion.PROTECT, to='iam.Realm')),
            ],
            options={
                'db_table': 'subjects',
                'default_permissions': [],
            },
        ),
    ]
