# Generated by Django 3.0.4 on 2020-03-16 02:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('iam', '0008_subjectstringproperty'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='subjectstringproperty',
            unique_together={('subject', 'kind')},
        ),
    ]
