"""Declares :class:`~django.contrib.admin.ModelAdmin` implementations."""
from .acceptedplatformagreement import AcceptedPlatformAgreementAdmin
from .platformagreementlanguage import PlatformAgreementLanguageAdmin
from .subjectregistration import SubjectRegistrationAdmin
